# v1.0.0 - 2017-05-13

- Replace aiopg with asyncpg. The database dsn string is now specified as a
  postgres:// URI.


# v0.1.2 - 2017-05-07

- Replace Makefile with tox.


# v0.1.1 - 2017-03-07

- Fix setup.py issues.


# v0.1.0 - 2017-03-07

- First release.
